@@ -98,8 +98,10 @@ main(int  argc,				/* I - Number of command-line args */
   ipp_attribute_t *attr;
   int     bytes;      /* Bytes copied */
   char uri[HTTP_MAX_URI];
-  char    *argv_nt[7];
-  int     outbuflen,filefd,exit_status,dup_status;
+  char    *argv_nt[8];
+  int     outbuflen, filefd, savestdout, exit_status, dup_status;
+  char buf[1024];
+  const char *serverbin;
   static const char *pattrs[] =
                 {
                   "printer-defaults"
@@ -189,7 +191,7 @@ main(int  argc,				/* I - Number of command-line args */
 	  break;
       }
       fprintf(stderr, "DEBUG: Read " CUPS_BROWSED_DEST_PRINTER " option: %s\n",
-	      ptr1);
+	      (ptr1 ? ptr1 : "Option not found"));
       if (ptr1 == NULL)
 	goto failed;
       /* Destination host is between double quotes, as double quotes are
@@ -222,7 +224,7 @@ main(int  argc,				/* I - Number of command-line args */
 	      queue_name);
       return (CUPS_BACKEND_STOP);
     }
-    strncpy(dest_host,ptr1,sizeof(dest_host));
+    strncpy(dest_host,ptr1,sizeof(dest_host) - 1);
     if (!strcmp(dest_host, "NO_DEST_FOUND")) {
       /* All remote queues are either disabled or not accepting jobs, let
 	 CUPS retry after the usual interval */
@@ -241,7 +243,7 @@ main(int  argc,				/* I - Number of command-line args */
       cups_option_t *options = NULL;
       int fd;
       char buffer[8192];
-      
+
       fprintf(stderr, "DEBUG: Received destination host name from cups-browsed: printer-uri %s\n",
 	      ptr1);
 
@@ -249,8 +251,7 @@ main(int  argc,				/* I - Number of command-line args */
 	 job */
       cupsSetUser(argv[2]);
       title = argv[3];
-      if (title == NULL)
-      {
+      if (title == NULL) {
 	if (argc == 7) {
 	  if ((title = strrchr(argv[6], '/')) != NULL)
 	    title ++;
@@ -279,9 +280,9 @@ main(int  argc,				/* I - Number of command-line args */
 	ptr4++;
       }
 
-      strncpy(printer_uri, ptr1, sizeof(printer_uri));
-      strncpy(document_format, ptr3, sizeof(document_format));
-      strncpy(resolution, ptr4, sizeof(resolution));
+      strncpy(printer_uri, ptr1, sizeof(printer_uri) - 1);
+      strncpy(document_format, ptr3, sizeof(document_format) - 1);
+      strncpy(resolution, ptr4, sizeof(resolution) - 1);
 
       fprintf(stderr,"DEBUG: Received job for the printer with the destination uri - %s, Final-document format for the printer - %s and requested resolution - %s\n",
 	      printer_uri, document_format, resolution);
@@ -299,15 +300,17 @@ main(int  argc,				/* I - Number of command-line args */
 	  bytes = write(fd, buffer, bytes);
 	close(fd);
 	filename = tempfile;
-      } else{
-	/** Use the filename on the command-line...*/
+      } else {
+	/* Use the filename on the command-line... */
 	filename    = argv[6];
 	tempfile[0] = '\0';
       }
 
       /* Copying the argument to a new char** which will be sent to the filter
-	 and the ipp backend*/
-      for (i = 0; i < 5; i++)
+	 and the ipp backend */
+      argv_nt[0] = calloc(strlen(printer_uri) + 8, sizeof(char));
+      strcpy(argv_nt[0], printer_uri);
+      for (i = 1; i < 5; i++)
 	argv_nt[i] = argv[i];
 
       /* Few new options will be added to the argv[5]*/
@@ -317,12 +320,14 @@ main(int  argc,				/* I - Number of command-line args */
 
       /* Filter pdftoippprinter.c will read the input from this file*/
       argv_nt[6] = filename;
+      argv_nt[7] = NULL;
       set_option_in_str(argv_nt[5], outbuflen, "output-format",
 			document_format);
       set_option_in_str(argv_nt[5], outbuflen, "Resolution",resolution);
       set_option_in_str(argv_nt[5], outbuflen, "cups-browsed-dest-printer",NULL);
       set_option_in_str(argv_nt[5], outbuflen, "cups-browsed",NULL);
       setenv("DEVICE_URI",printer_uri, 1);
+      fprintf(stderr, "Setting the device uri to  %s\n",printer_uri);
       fprintf(stderr, "Changed the argv[5] to %s\n",argv_nt[5]);
 
       filefd = cupsTempFd(tempfile_filter, sizeof(tempfile_filter));
@@ -332,17 +337,20 @@ main(int  argc,				/* I - Number of command-line args */
          to the backend, but having this temperory file will help us
          find whether the filter worked correctly and what was the
          document-format of the filtered output.*/
-      close(1);
-      dup_status = dup(filefd);
+      savestdout = dup(1);
+      dup_status = dup2(filefd, 1);
       if(dup_status < 0) {
         fprintf(stderr, "Could not write the output of pdftoippprinter printer to tmp file\n");
         return CUPS_BACKEND_FAILED;
       }
+      close(filefd);
 
       /* Calling pdftoippprinter.c filter*/
       apply_filters(7,argv_nt);
 
-      close(filefd);
+      /* Reset stdout to standard */
+      dup2(savestdout, 1);
+      close(savestdout);
 
       /* We will send the filtered output of the pdftoippprinter.c to
 	 the IPP Backend*/
@@ -362,17 +370,33 @@ main(int  argc,				/* I - Number of command-line args */
 	setenv("FINAL_CONTENT_TYPE", "application/PCLm", 1);
       else if(!strcmp(document_format,"pclxl"))
 	setenv("FINAL_CONTENT_TYPE", "application/vnd.hp-pclxl", 1);
+      else if(!strcmp(document_format,"postscript"))
+	setenv("FINAL_CONTENT_TYPE", "application/postscript", 1);
       else if(!strcmp(document_format,"pcl"))
 	setenv("FINAL_CONTENT_TYPE", "application/pcl", 1);
 
       ippDelete(response);
+      fprintf(stderr, "Passing the following arguments to the ipp backend\n");
+      /* Arguments sent to the ipp backend */
+      for (i = 0; i < 7; i ++) {
+	fprintf(stderr, "argv[%d]: %s\n", i, argv_nt[i]);
+      }
 
       /* The implicitclass backend will send the job directly to the
 	 ipp backend*/
+
       pid_t pid = fork();
-      if ( pid == 0 ) {
-	fprintf(stderr, "DEBUG: Started IPP Backend with pid: %d\n",getpid());
-	execv("/usr/lib/cups/backend/ipp",argv_nt);
+      if (pid == 0) {
+	serverbin = getenv("CUPS_SERVERBIN");
+	if (serverbin == NULL)
+	  serverbin = CUPS_SERVERBIN;
+	snprintf(buf, sizeof(buf) - 1, "%s/backend/ipp", serverbin);
+	fprintf(stderr, "DEBUG: Started IPP Backend (%s) with pid: %d\n",
+		buf, getpid());
+	execv(buf, argv_nt);
+	fprintf(stderr, "ERROR: Could not start IPP Backend (%s): %d %s\n",
+		buf, errno, strerror(errno));
+	return CUPS_BACKEND_FAILED;
       } else {
 	int status;
 	waitpid(pid, &status, 0);
