@@ -39,7 +39,7 @@
  * Local functions...
  */
 
-static void		flush_tile(cups_image_t *img);
+static int		flush_tile(cups_image_t *img);
 static cups_ib_t	*get_tile(cups_image_t *img, int x, int y);
 
 
@@ -614,7 +614,7 @@ cupsImageSetMaxTiles(
  * 'flush_tile()' - Flush the least-recently-used tile in the cache.
  */
 
-static void
+static int
 flush_tile(cups_image_t *img)		/* I - Image */
 {
   int		bpp;			/* Bytes per pixel */
@@ -622,12 +622,16 @@ flush_tile(cups_image_t *img)		/* I - Image */
 
 
   bpp  = cupsImageGetDepth(img);
+  if(img==NULL||img->first==NULL||img->first->tile==NULL)
+  {
+    return -1;
+  }
   tile = img->first->tile;
 
   if (!tile->dirty)
   {
     tile->ic = NULL;
-    return;
+    return 0;
   }
 
   if (img->cachefile < 0)
@@ -637,7 +641,7 @@ flush_tile(cups_image_t *img)		/* I - Image */
     {
       tile->ic    = NULL;
       tile->dirty = 0;
-      return;
+      return 0;
     }
 
     DEBUG_printf(("Created swap file \"%s\"...\n", img->cachename));
@@ -649,7 +653,7 @@ flush_tile(cups_image_t *img)		/* I - Image */
     {
       tile->ic    = NULL;
       tile->dirty = 0;
-      return;
+      return 0;
     }
   }
   else
@@ -658,7 +662,7 @@ flush_tile(cups_image_t *img)		/* I - Image */
     {
       tile->ic    = NULL;
       tile->dirty = 0;
-      return;
+      return 0;
     }
   }
 
@@ -668,6 +672,7 @@ flush_tile(cups_image_t *img)		/* I - Image */
 
   tile->ic    = NULL;
   tile->dirty = 0;
+  return 0;
 }
 
 
@@ -743,7 +748,11 @@ get_tile(cups_image_t *img,		/* I - Image */
     {
       DEBUG_printf(("Flushing old cache tile (%p)...\n", img->first));
 
-      flush_tile(img);
+      int res = flush_tile(img);
+      if(res)
+      {
+        return NULL;
+      }
       ic = img->first;
     }
 
